@@ -4,7 +4,7 @@ from wenxin_api.tasks.cloze import Cloze
 from wenxin_api.tasks.composition import Composition
 from wenxin_api.tasks.couplet import Couplet
 from wenxin_api.tasks.free_qa import FreeQA
-from wenxin_api.tasks.noval import Noval
+from wenxin_api.tasks.novel import Novel
 from wenxin_api.tasks.official_documents import OfficialDocuments
 from wenxin_api.tasks.summarization import Summarization
 from wenxin_api.tasks.text_generation import TextGeneration
\ No newline at end of file
